@@ -1,15 +1,14 @@
 package com.clarkware.junitperf;
 
 import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
- * The <code>ExampleResponseTimeUnderLoadTest</code> demonstrates how to 
- * decorate a <code>TimedTest</code> as a <code>LoadTest</code> to measure 
- * response time under load.
+ * The <code>ExampleResponseTimeUnderLoadTest</code> demonstrates 
+ * how to decorate a <code>TimedTest</code> as a <code>LoadTest</code> 
+ * to measure response time under load.
  *
- * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
- * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
+ * @author <b>Mike Clark</b>
+ * @author Clarkware Consulting, Inc.
  *
  * @see com.clarkware.junitperf.LoadTest
  * @see com.clarkware.junitperf.TimedTest
@@ -26,10 +25,7 @@ public class ExampleResponseTimeUnderLoadTest {
         Test timedTest = new TimedTest(testCase, maxElapsedTime);
         Test loadTest = new LoadTest(timedTest, maxUsers);
  
-        TestSuite suite = new TestSuite();
-        suite.addTest(loadTest);
-        
-        return suite;
+        return loadTest;
     }
     
     public static void main(String args[]) {
