@@ -1,15 +1,14 @@
 package com.clarkware.junitperf;
 
 import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
  * The <code>ExampleThroughputUnderLoadTest</code> demonstrates how to 
- * decorate a <code>LoadTest</code> as a <code>TimedTest</code> to measure 
- * throughput under load.
+ * decorate a <code>LoadTest</code> as a <code>TimedTest</code> 
+ * to measure throughput under load.
  *
- * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
- * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
+ * @author <b>Mike Clark</b>
+ * @author Clarkware Consulting, Inc.
  *
  * @see com.clarkware.junitperf.LoadTest
  * @see com.clarkware.junitperf.TimedTest
@@ -26,10 +25,7 @@ public class ExampleThroughputUnderLoadTest {
         Test loadTest = new LoadTest(testCase, maxUsers);
         Test timedTest = new TimedTest(loadTest, maxElapsedTime);
 
-        TestSuite suite = new TestSuite();
-        suite.addTest(timedTest);
-        
-        return suite;
+        return timedTest;
     }
     
     public static void main(String args[]) {
