@@ -1,14 +1,13 @@
 package com.clarkware.junitperf;
 
 import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
- * The <code>ExampleTimedTest</code> demonstrates how to decorate a 
- * <code>Test</code> as a <code>TimedTest</code>.
+ * The <code>ExampleTimedTest</code> demonstrates how to 
+ * decorate a <code>Test</code> as a <code>TimedTest</code>.
  *
- * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
- * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
+ * @author <b>Mike Clark</b>
+ * @author Clarkware Consulting, Inc.
  *
  * @see com.clarkware.junitperf.TimedTest
  */
@@ -24,10 +23,7 @@ public class ExampleTimedTest {
 		Test testCase = new ExampleTestCase("testOneSecondResponse");
 		Test timedTest = new TimedTest(testCase, maxElapsedTimeInMillis);
 
-		TestSuite suite = new TestSuite();
-		suite.addTest(timedTest);
-
-		return suite;
+		return timedTest;
 	}
 
 	public static void main(String args[]) {
